==> apache-fory-v0.13.0-src.tar.gz: apache-fory-v0.13.0-src/javascript/packages/fory/lib/gen/binary.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { TypeInfo } from "../typeInfo";
import { CodecBuilder } from "./builder";
import { BaseSerializerGenerator, RefState } from "./serializer";
import { CodegenRegistry } from "./router";
import { InternalSerializerType } from "../type";
import { Scope } from "./scope";

class BinarySerializerGenerator extends BaseSerializerGenerator {
  typeInfo: TypeInfo;

  constructor(typeInfo: TypeInfo, builder: CodecBuilder, scope: Scope) {
    super(typeInfo, builder, scope);
    this.typeInfo = typeInfo;
  }

  writeStmt(accessor: string): string {
    return `
        ${this.builder.writer.uint8(1)}
        ${this.builder.writer.uint32(`${accessor}.byteLength`)}
        ${this.builder.writer.buffer(accessor)}
        `;
  }

  readStmt(accessor: (expr: string) => string, refState: RefState): string {
    const result = this.scope.uniqueName("result");
    return `
        ${this.builder.reader.uint8()}
        ${result} = ${this.builder.reader.buffer(this.builder.reader.int32())};
        ${this.maybeReference(result, refState)};
        ${accessor(result)}
        `;
  }

  getFixedSize(): number {
    return 8;
  }

  needToWriteRef(): boolean {
    return Boolean(this.builder.fory.config.refTracking);
  }
}

CodegenRegistry.register(InternalSerializerType.BINARY, BinarySerializerGenerator);

==> apache-fory-0.15.0-src.tar.gz: apache-fory-0.15.0-src/javascript/packages/fory/lib/gen/binary.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import { TypeInfo } from "../typeInfo";
import { CodecBuilder } from "./builder";
import { BaseSerializerGenerator } from "./serializer";
import { CodegenRegistry } from "./router";
import { TypeId } from "../type";
import { Scope } from "./scope";

class BinarySerializerGenerator extends BaseSerializerGenerator {
  typeInfo: TypeInfo;

  constructor(typeInfo: TypeInfo, builder: CodecBuilder, scope: Scope) {
    super(typeInfo, builder, scope);
    this.typeInfo = typeInfo;
  }

  write(accessor: string): string {
    return `
        ${this.builder.writer.uint8(1)}
        ${this.builder.writer.uint32(`${accessor}.byteLength`)}
        ${this.builder.writer.buffer(accessor)}
        `;
  }

  read(accessor: (expr: string) => string, refState: string): string {
    const result = this.scope.uniqueName("result");
    return `
        ${this.builder.reader.uint8()}
        ${result} = ${this.builder.reader.buffer(this.builder.reader.int32())};
        ${this.maybeReference(result, refState)};
        ${accessor(result)}
        `;
  }

  getFixedSize(): number {
    return 8;
  }
}

CodegenRegistry.register(TypeId.BINARY, BinarySerializerGenerator);
